Crate retryable_result

Crate retryable_result 

Re-exports

pub use retryable::Retryable;
pub use retryable::RetryableResult;
pub use try_again::repeatedly_try;

Modules

retryable
try_again
when we have something that returns both recoverable and nonrecoverable errors as it’s error values, try repeatedly until - success - there are enough recoverable errors that the wait_time on Retryable says it is time to give up - a fatal error